# nakdimon-ort

[Nakdimon](https://github.com/elazarg/nakdimon) diacritizer with onnxruntime

## Setup

```console
pip install nakdimon-ort
```

Please see examples. you also need `nakdimon.onnx` and `config.json` files.

## Examples

See [examples](examples)